The New York Times - Breaking News, World News & Multimedia
Description: The New York Times: Find breaking news, multimedia, reviews & opinion on Washington, business, sports, movies, travel, books, jobs, education, real estate, cars & more at nytimes.com.
Keywords: Trump-Ukraine Whistle-blower Complaint and Impeachment Inquiry,US Politics,Democrats,House of Representatives,Congress,Senate,Congress,Nancy Pelosi,Donald Trump,Impeachment,US Constitution;United States Constitution,Justice Roberts,Mitch McConnell,2020 Election,Presidential debates;Democratic debates;2020 debates,Primaries,Joe Biden,Pete Buttigieg,Amy Klobuchar,Bernard Sanders;Bernie Sanders,Elizabeth Warren,Des Moines Iowa,Tom Steyer,Voting,Iowa,Iran plane crash,Plane Crash,Video Recordings, Downloads and Streaming,Islamic Revolutionary Guards,Iran,Tehran,Mueller report;Russia Investigation;Russian meddling in US elections,Special prosecutor,Lobbying,FBI,Michael Flynn,China,International trade,Cars,Wind power,Solar energy,US Foreign Policy,Mergers and Acquisitions,Corporate espionage,Computer security,Computers and the Internet,Tech Industry,Software,Naval Air Station Pensacola,Privacy,iPhone,Apple,Justice Department,William P Barr,Timothy D Cook,Corporate Social Responsibility

Continue reading the main story

## Listen to ‘The Daily’

The Russian plan for hacking the 2020 election.

## The Book Review Podcast

Anna Wiener discusses her new memoir, “Uncanny Valley.”

## Sign Up for the ‘Wait ...’ Newsletter

How tech and fame are changing our lives — for better or worse.

## Documents Provide New Details of Trump’s Pressure Campaign on Ukraine

- The records and text messages described a campaign conducted by Rudy Giuliani to unearth damaging information in Ukraine about Joe Biden and his son.
- The material intensified demands on Senate Republicans to include witnesses in the impeachment trial. The House votes Wednesday to start the proceeding.

908 comments
Chief Justice John G. Roberts Jr. at the State of the Union last year. Doug Mills/The New York Times

## Trump’s Impeachment Trial Is a Perilous Duty for the Chief Justice

Chief Justice John Roberts’s role may be mostly ceremonial, but signs of partisanship could damage the Supreme Court.

656 comments

## Here’s what to watch for on impeachment in the House and Senate today.

## Democrats Debate War and a Woman’s Chance at the White House

The rift between Bernie Sanders and Elizabeth Warren over electability rose to the surface in the Democratic debate, and the candidates also sparred over their stances on war.

transcript
0:00/2:57
-2:57

transcript

## Watch: Highlights from the Democratic Debate

#### Six presidential candidates went head-to-head in the final debate before the Iowa caucuses.

  “In 2018, you told her that you did not believe that a woman could win the election.” “As a matter of fact, I didn’t say it. If any of the women on this stage or any of the men on this stage win the nomination — I hope that’s not the case, I hope it’s me — but if they do, I will do everything in my power to make sure that they are elected in order to defeat the most dangerous president in the history of our country.” “What did you think when Senator Sanders told you a woman could not win the election?” “I disagreed. Look at the men on this stage. Collectively they have lost 10 elections. The only people on this stage who have won every single election that they’ve been in are the women — Amy and me.” [cheering] “I have won every race, every place, every time.” “I defeated an incumbent Republican —” “When?” “— running for Congress.” “When?” “1990.” “That’s how I won — beat a Republican congressman.” “Wasn’t that 30 years ago?” “I beat an incumbent Republican congressman —” “And I said, I was the only one who has beaten an incumbent Republican in 30 years.” “The two great foreign policy disasters of our lifetimes are the war in Vietnam and the war in Iraq. Both of those wars were based on lies.” “I was part of that deal to get the nuclear agreement with Iran, bringing together the rest of the world, including some of the folks who aren’t friendly to us.” “I did everything I could to prevent that war. Joe saw it differently.” “It’s time to get our combat troops home.” “If we’re going to do something with North Korea, we’re going to have to do it in concert with our allies.” “We have farmers here in Iowa who are hurting.” “I have the most endorsements of current Iowa legislators and former Iowa legislators in this race.” “And to have support right here in Iowa from some of the most recognizable black elected leaders ...” “I am going to be able to stand across from him on that debate stage and say, to my friends in Iowa, the Midwest is not flyover country.” “When he gets to the tough talk and the chest thumping, he’ll have to stand next to an American war veteran and explain how he pretended bone spurs made him ineligible to serve.” “I’ve been the object of his affection now more than anybody else on this stage. I’ve taken all the hits he can deliver and I’m getting better in the polls ...”

Six presidential candidates went head-to-head in the final debate before the Iowa caucuses. Tamir Kalifa for The New York Times

## Mr. Sanders and Ms. Warren say they are friends. But competitive campaigns tend to test the definition of “friendship.”

## Here are 6 takeaways from the Democratic debate.

456 comments

## New Video Shows Two Iranian Missiles Hit Ukrainian Plane

Security camera footage verified by The Times shows that two missiles fired 30 seconds apart took down Flight 752, killing all aboard.

A video shows that the Iranian military launched two missiles. The plane, ablaze, continued flying for several minutes before crashing. The New York Times

## Michael Flynn Moves to Withdraw Guilty Plea in Russia Inquiry

Once cited by the special counsel team as an exemplary cooperating witness, President Trump’s former national security adviser had grown combative.

## Why the U.S.-China Trade Deal Targets Corporate Secrets

Companies accuse Chinese rivals of swiping technology. In a partial deal to be signed today, Beijing promises to ban this, but enforcement could be hard.

Technology companies like Apple set up ventures with local partners to handle data in China to comply with the country’s internal security laws. Lam Yik Fei for The New York Times

## Apple Takes a (Cautious) Stand Against Opening a Killer’s iPhones

The Silicon Valley giant is preparing for a legal fight over encryption, even as it works to reduce tensions with the Justice Department.

Two iPhones used by the gunman in a Pensacola, Fla., shooting are the focus of a fight between Apple and the Justice Department. Jim Lo Scalzo/EPA, via Shutterstock

### Opinion

## Winners and Losers of the Democratic Debate

Our columnists and contributors give their rankings.

## Amy Klobuchar Wants to Get It Done

Ms. Klobuchar interviews for the Times’s editorial board’s endorsement.

Frank Bruni

## Warren and Klobuchar Teach the Boys a Lesson

The Editorial Board

## Take Impeachment Seriously, Senators

Ronald J. Krotoszynski Jr.

## The Senate Must Reject Trump’s Privilege Claim on Witnesses

## Andrew Yang Is Listening

Thomas L. Friedman

## Trump’s Code of Dishonor

Betsy Cooper

## I’m Six Weeks Pregnant, and I’m Telling the World

Eswar Prasad

## Trump Gets His Trade Deal, China Gets the Win

Ken Burns

## Women May Finally Be Declared Equal

Max Siollun

## Nigeria Is Haunted by Its Civil War

### Editors’ Picks

Jackie Molloy for The New York Times

## The Sex Scene Evolves for the #MeToo Era

Studios and theaters are hiring intimacy coordinators to help actors. The twist: They’re also making the scenes sexier.

Magazine

## Andy Warhol Through the Lens

Photography was Andy Warhol’s secret weapon — the architecture of his oeuvre. A new show highlights many of his rarely seen images.

Arts

## Longing for Stability After a Childhood in Hospitals

Despite a genetic disorder and family financial struggles, Silas Waller is determined to get on a path to financial security.

Neediest Cases

### Advertisement

Continue reading the main story

We’d like your thoughts on the New York Times home page experience.Let us know what you think